#!/bin/bash

#***************************************************************************************
#
# This is a basic script to automatically install the Jabber Server and it's components.         
# 
# Authors: Tony Guntharp <fusion94@valinux.com>
# Tweaks: Jeremie <jeremie@jabber.org>
#	    
#***************************************************************************************


# Use the arg as a custom prefix
PREFIX=
LOCAL=/usr/local
if [ $1 ]
then
  if mkdir -p $1
  then
    PREFIX="--prefix=$1"
    LOCAL=$1
  else
    echo Error!
    echo
    echo $1 is not a valid install directory.
    echo
    exit 1
  fi
else
  if [ `id -u` != 0 ]
  then
    echo Error!
    echo
    echo "Only root (the superuser) can install the Jabber Server and all it's components"
    echo to /usr/local.  Please use the \"su\" command to get root privileges, or
    echo specify a custom folder on the command line: ./install.sh /home/user/jabber
    echo
    exit 1
  fi
fi

# Unpack the packages
gunzip < pth-1.3.3.tar.gz | tar xvf -
gunzip < adns-0.7.tar.gz | tar xvf -
gunzip < libxode-0.9.tar.gz | tar xvf -
gunzip < libjabber-0.9.tar.gz | tar xvf -
gunzip < libetherx-0.9.tar.gz | tar xvf -
gunzip < jabber-transport-0.9.tar.gz | tar xvf -

# Start with Portable Threads 
# Installs under /usr/local by default
cd pth-1.3.3
echo test $PREFIX
./configure $PREFIX && make && make test && make install
cd ..

# Install Asynchronous DNS stuff
cd adns-0.7
./configure $PREFIX && make && make install
cd ..

# Install libxode
cd libxode-0.9
./configure $PREFIX && make && make install
/sbin/ldconfig
cd ..

# Install libjabber
cd libjabber-0.9
./configure $PREFIX --with-libxode=$LOCAL && make && make install
/sbin/ldconfig
cd ..

# Install libetherx
cd libetherx-0.9
./configure $PREFIX && make && make install
/sbin/ldconfig
cd ..

# Install jabber-transport
cd jabber-transport-0.9
./configure $PREFIX && make && make install
cd ..

# Clean up the Source Directories
rm -rf pth-1.3.3
rm -rf adns-0.7
rm -rf libxode-0.9
rm -rf libjabber-0.9
rm -rf libetherx-0.9
rm -rf jabber-transport-0.9

# Clear the screen
clear

echo
echo You will now need to edit $LOCAL/etc/jserver.xml to configure for your system.
echo
echo See the jserver.xml man page or the Jabber Server mini-HOWTO on
echo http://docs.jabber.org for more configuration options.
echo
echo You can start the server:
echo
echo "$LOCAL/bin/jserver &"
echo  
echo If that does not work, try starting them from different terminal windows
echo with the debug flag set and watch for errors.
echo
echo $LOCAL/bin/jserver -D
echo
echo Complete information about configuration can be found in the Jabber Server
echo mini-HOWTO at http://docs.jabber.org/.
echo


